@@ -5,7 +5,7 @@ from nwon_django_toolbox.tests.api_method_tests.check_delete import (
 from nwon_django_toolbox.tests.api_method_tests.check_get import check_get_basics
 from nwon_django_toolbox.tests.api_method_tests.check_patch import (
     check_patch_basics,
-    check_patch_not_allowed,
+    check_patch_method_not_allowed,
     check_patch_parameters_failing,
     check_patch_parameters_successful,
     check_patch_read_only_field,
@@ -46,7 +46,7 @@ __all__ = [
     "check_delete_not_allowed",
     "check_get_basics",
     "check_patch_basics",
-    "check_patch_not_allowed",
+    "check_patch_method_not_allowed",
     "check_patch_parameters_failing",
     "check_patch_parameters_successful",
     "check_patch_read_only_field",
