@@ -3,7 +3,7 @@ from typing import List, Optional
 from django.conf import settings
 from nwon_baseline.directory_helper import clean_directory, create_pathes
 
-from nwon_django_toolbox.typings import CeleryFolder
+from nwon_django_toolbox.typings.celery.celery_folders import CeleryFolder
 
 
 def clean_all_celery_messages():
